/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2011-2023 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::multipliedFixedValueFvPatchField

Description
    This boundary condition provides a multiplied fixed value condition.

Usage
    \table
        Property     | Description             | Required    | Default value
        multipliedValue | multiplied value           | yes         |
    \endtable

    Example of the boundary condition specification:
    \verbatim
    <patchName>
    {
        type            	multipliedFixedValue;
        toBeScaledValue         uniform (10 0 0);
        scale 			2;
    }
    \endverbatim

    Note:
        The multipliedValue entry is a Function1 type, able to describe time
        varying functions.  The example above gives the usage for supplying a
        constant value to be scaled and a scale factor.

See also
    Foam::Function1s
    Foam::fixedValueFvPatchField

SourceFiles
    multipliedFixedValueFvPatchField.C

-----> this was uniformFixedValue.H file <-----------

\*---------------------------------------------------------------------------*/

#ifndef multipliedFixedValueFvPatchField_H
#define multipliedFixedValueFvPatchField_H

#include "fixedValueFvPatchFields.H"
#include "Function1.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                Class multipliedFixedValueFvPatchField Declaration
\*---------------------------------------------------------------------------*/

template<class Type>
class multipliedFixedValueFvPatchField
:
    public fixedValueFvPatchField<Type>
{
    // Private Data

        autoPtr<Function1<Type>> multipliedValue_;
        
        // Check the fixedProfile.C file for an example
        scalar scale_;


public:

    //- Runtime type information
    TypeName("multipliedFixedValue");


    // Constructors

        //- Construct from patch, internal field and dictionary
        multipliedFixedValueFvPatchField
        (
            const fvPatch&,
            const DimensionedField<Type, volMesh>&,
            const dictionary&
        );

        //- Construct by mapping given multipliedFixedValueFvPatchField
        //  onto a new patch
        multipliedFixedValueFvPatchField
        (
            const multipliedFixedValueFvPatchField<Type>&,
            const fvPatch&,
            const DimensionedField<Type, volMesh>&,
            const fieldMapper&
        );

        //- Disallow copy without setting internal field reference
        multipliedFixedValueFvPatchField
        (
            const multipliedFixedValueFvPatchField<Type>&
        ) = delete;

        //- Copy constructor setting internal field reference
        multipliedFixedValueFvPatchField
        (
            const multipliedFixedValueFvPatchField<Type>&,
            const DimensionedField<Type, volMesh>&
        );

        //- Construct and return a clone setting internal field reference
        virtual tmp<fvPatchField<Type>> clone
        (
            const DimensionedField<Type, volMesh>& iF
        ) const
        {
            return tmp<fvPatchField<Type>>
            (
                new multipliedFixedValueFvPatchField<Type>(*this, iF)
            );
        }


    // Member Functions

        //- Update the coefficients associated with the patch field
        virtual void updateCoeffs();

        //- Write
        virtual void write(Ostream&) const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#ifdef NoRepository
    #include "multipliedFixedValueFvPatchField.C"
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
